/*
 * $Id: Main.java,v 1.3 2003/04/25 15:18:26 znerd Exp $
 */
package org.znerd.xsltcompress.examples.print;

import java.io.FileReader;
import java.io.FileWriter;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import org.apache.commons.cli.BasicParser;
import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.Option;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.Parser;
import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;
import org.znerd.xsltcompress.XSLTCompressor;
import org.znerd.xmlenc.XMLOutputter;
import org.znerd.xmlenc.sax.SAXOutputter;

/**
 * Program that reads an XSLT document from the standard input stream and
 * prints it to the standard output stream.
 *
 * @version $Revision: 1.3 $ $Date: 2003/04/25 15:18:26 $
 * @author Ernst de Haan (<a href="mailto:znerd@FreeBSD.org">znerd@FreeBSD.org</a>)
 */
public final class Main extends Object {

   //-------------------------------------------------------------------------
   // Class fields
   //-------------------------------------------------------------------------

   /**
    * The encoding to use when generating XML output.
    */
   private static final String ENCODING = "US-ASCII";


   //-------------------------------------------------------------------------
   // Class functions
   //-------------------------------------------------------------------------

   public static final void main(String[] args)
   throws Exception {


      // Create individual options
      Option inputOption = new Option("i", "input", true, "Use the specified input file instead of stdin.");
      Option outputOption = new Option("o", "output", true, "Use the specified output file instead of stdout.");

      // Register all options
      Options options = new Options();
      options.addOption(inputOption);
      options.addOption(outputOption);

      // Parse command line arguments
      Parser cmdParser = new BasicParser();
      CommandLine cmd = cmdParser.parse(options, args);

      // Determine the input and output streams to use
      Reader reader = cmd.hasOption(inputOption.getOpt())
                    ? new FileReader(cmd.getOptionValue(inputOption.getOpt()))
                    : new InputStreamReader(System.in);
      Writer writer = cmd.hasOption(outputOption.getOpt())
                    ? new FileWriter(cmd.getOptionValue(outputOption.getOpt()))
                    : new OutputStreamWriter(System.out);

      // Initialize the XMLOutputter
      XMLOutputter xmlOutputter = new XMLOutputter(writer, ENCODING);
      SAXOutputter outputter = new SAXOutputter(xmlOutputter);

      // Create a SAX parser
      final String parserClass = "org.apache.xerces.parsers.SAXParser";
      XMLReader parser = XMLReaderFactory.createXMLReader(parserClass);

      // Create a compressor filter and link it
      XSLTCompressor filter = new XSLTCompressor(parser);
      filter.setContentHandler(outputter);

      // Parse the standard input stream
      InputSource inputSource = new InputSource(reader);
      filter.parse(inputSource);
   }


   //-------------------------------------------------------------------------
   // Constructors
   //-------------------------------------------------------------------------

   /**
    * Constructs a new <code>Main</code> object.
    */
   private Main() {
      // empty
   }


   //-------------------------------------------------------------------------
   // Fields
   //-------------------------------------------------------------------------

   //-------------------------------------------------------------------------
   // Methods
   //-------------------------------------------------------------------------
}
